processor

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 29, 2026 License: BSD-3-Clause Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type InstrumentingProcessor

type InstrumentingProcessor struct {
	// contains filtered or unexported fields
}

InstrumentingProcessor is a decorator that adds instrumentation to a Processor.

func NewInstrumentingProcessor

func NewInstrumentingProcessor(processor Processor, instrumentor *telemetry.Instrumentor, tracer trace.Tracer) *InstrumentingProcessor

NewInstrumentingProcessor creates a new InstrumentingProcessor.

func (*InstrumentingProcessor) ProcessRecord

func (p *InstrumentingProcessor) ProcessRecord(ctx context.Context, record *kgo.Record, producer *internalKgo.Producer) (err error)

ProcessRecord processes a Kafka record and instruments the operation.

type Processor

type Processor interface {
	ProcessRecord(ctx context.Context, record *kgo.Record, producer *internalKgo.Producer) error
}

Processor defines the interface for processing Kafka records.

Jump to