Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Consumer ¶
type Consumer struct {
// contains filtered or unexported fields
}
Consumer handles the message processing logic.
func New ¶
func New(client KafkaClient, processor processor.Processor, logger *zap.SugaredLogger, producer *internalKgo.Producer) *Consumer
type Fetches ¶
type Fetches interface {
Errors() []kgo.FetchError
EachRecord(func(*kgo.Record))
}
Fetches defines the interface for the result of a poll operation.
type KafkaClient ¶
KafkaClient defines the interface for the Kafka client operations we need.
type KgoClientAdapter ¶
KgoClientAdapter adapts the concrete *kgo.Client to our KafkaClient interface.
func (*KgoClientAdapter) Close ¶
func (a *KgoClientAdapter) Close()
func (*KgoClientAdapter) PollFetches ¶
func (a *KgoClientAdapter) PollFetches(ctx context.Context) Fetches
Click to show internal directories.
Click to hide internal directories.