Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InstrumentingProcessor ¶
type InstrumentingProcessor struct {
// contains filtered or unexported fields
}
InstrumentingProcessor is a decorator that adds instrumentation to a Processor.
func NewInstrumentingProcessor ¶
func NewInstrumentingProcessor(processor Processor, instrumentor *telemetry.Instrumentor, tracer trace.Tracer) *InstrumentingProcessor
NewInstrumentingProcessor creates a new InstrumentingProcessor.
func (*InstrumentingProcessor) ProcessRecord ¶
func (p *InstrumentingProcessor) ProcessRecord(ctx context.Context, record *kgo.Record, producer *internalKgo.Producer) (err error)
ProcessRecord processes a Kafka record and instruments the operation.
Click to show internal directories.
Click to hide internal directories.